@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.0902';
+our $VERSION = '0.0903';
 
 use Moo;
 use MIDI::Simple;
@@ -142,6 +142,41 @@ sub metronome34 {
 }
 
 
+sub metronome54 {
+    my $self = shift;
+    my $bars = shift || $self->bars;
+    for my $n (1 .. $bars) {
+        $self->note($self->quarter, $self->closed_hh, $self->kick);
+        $self->note($self->quarter, $self->closed_hh);
+        $self->note($self->quarter, $self->closed_hh, $self->snare);
+        $self->note($self->quarter, $self->closed_hh);
+        if ($n % 2) {
+            $self->note($self->quarter, $self->closed_hh);
+        }
+        else {
+            $self->note($self->eighth, $self->closed_hh);
+            $self->note($self->eighth, $self->closed_hh, $self->kick);
+        }
+    }
+}
+
+
+sub metronome58 {
+    my $self = shift;
+    my $bars = shift || $self->bars;
+    for my $n (1 .. $bars) {
+        $self->note($self->eighth, $self->closed_hh, $self->kick);
+        $self->note($self->sixteenth, $self->closed_hh);
+        $self->note($self->sixteenth, $self->kick);
+        $self->note($self->eighth, $self->closed_hh, $self->snare);
+        $self->note($self->sixteenth, $self->closed_hh);
+        $self->note($self->sixteenth, $self->snare);
+        $self->note($self->sixteenth, $self->closed_hh);
+        $self->note($self->sixteenth, $self->kick);
+    }
+}
+
+
 sub write {
     my $self = shift;
     $self->score->write_score( $self->file );
@@ -161,7 +196,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.0902
+version 0.0903
 
 =head1 SYNOPSIS
 
@@ -357,6 +392,20 @@ eighth-note kicks.
 
 Add a steady 3/4 beat to the score.
 
+=head2 metronome54
+
+  $d->metronome54;
+  $d->metronome54($bars);
+
+Add a 5/4 beat to the score.
+
+=head2 metronome58
+
+  $d->metronome58;
+  $d->metronome58($bars);
+
+Add a 5/8 beat to the score.
+
 =head2 write
 
 Output the score to the default F<*.mid> file or one given to the
